Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1177)

Unified Diff: Source/core/loader/FrameLoader.h

Issue 517043003: Move Frame to the Oilpan heap. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Update OilpanExpectations Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/loader/FrameLoader.h
diff --git a/Source/core/loader/FrameLoader.h b/Source/core/loader/FrameLoader.h
index 4105569918b64d59cdffd3ef0f2c559dba4e988d..67c4daf2a9a4cf1ea080ddbfa0fd955be9f4dc84 100644
--- a/Source/core/loader/FrameLoader.h
+++ b/Source/core/loader/FrameLoader.h
@@ -41,6 +41,7 @@
#include "core/loader/HistoryItem.h"
#include "core/loader/MixedContentChecker.h"
#include "platform/Timer.h"
+#include "platform/heap/Handle.h"
#include "platform/network/ResourceRequest.h"
#include "wtf/Forward.h"
#include "wtf/HashSet.h"
@@ -72,8 +73,9 @@ struct WindowFeatures;
bool isBackForwardLoadType(FrameLoadType);
-class FrameLoader {
+class FrameLoader FINAL {
WTF_MAKE_NONCOPYABLE(FrameLoader);
+ ALLOW_ONLY_INLINE_ALLOCATION();
public:
static ResourceRequest requestFromHistoryItem(HistoryItem*, ResourceRequestCachePolicy);
@@ -100,8 +102,8 @@ public:
void stopAllLoaders();
void stopLoading();
bool closeURL();
- // FIXME: clear() is trying to do too many things. We should break it down into smaller functions.
- void clear();
+ // FIXME: dispose() is trying to do too many things. We should break it down into smaller functions.
+ void dispose(bool clearFrameContents);
void replaceDocumentWhileExecutingJavaScriptURL(const String& source, Document* ownerDocument);
// Sets a timer to notify the client that the initial empty document has
@@ -189,6 +191,8 @@ public:
void restoreScrollPositionAndViewState();
+ void trace(Visitor*);
+
private:
bool allChildrenAreComplete() const; // immediate children, not all descendants
@@ -223,7 +227,7 @@ private:
void scheduleCheckCompleted();
- LocalFrame* m_frame;
+ RawPtrWillBeMember<LocalFrame> m_frame;
// FIXME: These should be OwnPtr<T> to reduce build times and simplify
// header dependencies unless performance testing proves otherwise.
@@ -243,7 +247,7 @@ private:
RefPtr<DocumentLoader> m_documentLoader;
RefPtr<DocumentLoader> m_provisionalDocumentLoader;
RefPtr<DocumentLoader> m_policyDocumentLoader;
- OwnPtr<FetchContext> m_fetchContext;
+ OwnPtrWillBeMember<FetchContext> m_fetchContext;
RefPtr<HistoryItem> m_currentItem;
RefPtr<HistoryItem> m_provisionalItem;

Powered by Google App Engine
This is Rietveld 408576698